import React from 'react';
import { TypeAttributes, FormControlBaseProps, WithAsProps, RsRefForwardingComponent } from '../@types/common';
/**
 * Props that FormControl passes to its accepter
 */
export declare type FormControlAccepterProps<ValueType = any> = FormControlBaseProps<ValueType>;
export interface FormControlProps<P = any, ValueType = any> extends WithAsProps, Omit<React.HTMLAttributes<HTMLFormElement>, 'value' | 'onChange'> {
    /** Proxied components */
    accepter?: React.ElementType<P & FormControlBaseProps<ValueType>>;
    /** The name of form-control */
    name: string;
    /** Value */
    value?: ValueType;
    /** Callback fired when data changing */
    onChange?(value: ValueType, event: React.SyntheticEvent<HTMLElement>): void;
    /** The data validation trigger type, and it wiill overrides the setting on <Form> */
    checkTrigger?: TypeAttributes.CheckTrigger;
    /** Show error messages */
    errorMessage?: React.ReactNode;
    /** The placement of error messages */
    errorPlacement?: TypeAttributes.Placement8;
    /** Make the control readonly */
    readOnly?: boolean;
    /** Render the control as plain text */
    plaintext?: boolean;
    /** Disable the form control. */
    disabled?: boolean;
    /** Asynchronous check value */
    checkAsync?: boolean;
}
declare const FormControl: RsRefForwardingComponent<'div', FormControlProps>;
export default FormControl;
